==> joomla1_0_6JP_to_1_0_9JP.zip: joomla1_0_6JP_to_1_0_9JP/administrator/modules/mod_quickicon.php <==
<?php
/**
* @version $Id: mod_quickicon.php 1004 2005-11-13 17:18:18Z stingrey $
* @package Joomla
* @copyright Copyright (C) 2005 Open Source Matters. All rights reserved.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
* Joomla! is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/

// no direct access
defined( '_VALID_MOS' ) or die( 'Restricted access' );

if (!defined( '_JOS_QUICKICON_MODULE' )) {
	/** ensure that functions are declared only once */
	define( '_JOS_QUICKICON_MODULE', 1 );	

	function quickiconButton( $link, $image, $text ) {
		?>
		<div style="float:left;">
			<div class="icon">
				<a href="<?php echo $link; ?>">
					<?php echo mosAdminMenus::imageCheckAdmin( $image, '/administrator/images/', NULL, NULL, $text ); ?>
					<span><?php echo $text; ?></span>
				</a>
			</div>
		</div>
		<?php
	}
	
	?>
	<div id="cpanel">
		<?php
		$link = 'index2.php?option=com_content&amp;sectionid=0&amp;task=new';
		quickiconButton( $link, 'module.png', 'コンテンツアイテム追加' );
	
		$link = 'index2.php?option=com_content&sectionid=0';
		quickiconButton( $link, 'addedit.png', 'コンテンツアイテム管理' );
	
		$link = 'index2.php?option=com_typedcontent';
		quickiconButton( $link, 'addedit.png', '静的コンテンツ管理' );
	
		$link = 'index2.php?option=com_frontpage';
		quickiconButton( $link, 'frontpage.png', 'フロントページ管理' );
	
		$link = 'index2.php?option=com_sections&amp;scope=content';
		quickiconButton( $link, 'sections.png', 'セクション管理' );
	
		$link = 'index2.php?option=com_categories&amp;section=content';
		quickiconButton( $link, 'categories.png', 'カテゴリー管理' );
	
		$link = 'index2.php?option=com_media';
		quickiconButton( $link, 'mediamanager.png', 'メディア管理' );
	
		if ( $my->gid > 23 ) {
			$link = 'index2.php?option=com_trash';
			quickiconButton( $link, 'trash.png', 'ゴミ箱' );
		}
	
		if ( $my->gid > 23 ) {
			$link = 'index2.php?option=com_menumanager';
			quickiconButton( $link, 'menu.png', 'メニュー管理' );
		}
	
		if ( $my->gid > 24 ) {
			$link = 'index2.php?option=com_languages';
			quickiconButton( $link, 'langmanager.png', 'ランゲージ管理' );
		}
	
		if ( $my->gid > 23 ) {
			$link = 'index2.php?option=com_users';
			quickiconButton( $link, 'user.png', 'ユーザ管理' );
		}
	
		if ( $my->gid > 24 ) {
			$link = 'index2.php?option=com_config&hidemainmenu=1';
			quickiconButton( $link, 'config.png', 'グローバル・コンフィグレーション' );
		}
		?>
	</div>
	<?php
}
?>

==> joomla1_0_7JP_to_1_0_11JP.zip: joomla1_0_7JP_to_1_0_11JP/administrator/modules/mod_quickicon.php <==
<?php
/**
* @version $Id: mod_quickicon.php 4806 2006-08-28 17:17:08Z stingrey $
* @package Joomla
* @copyright Copyright (C) 2005 Open Source Matters. All rights reserved.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
* Joomla! is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/

// no direct access
defined( '_VALID_MOS' ) or die( 'Restricted access' );

if (!defined( '_JOS_QUICKICON_MODULE' )) {
	/** ensure that functions are declared only once */
	define( '_JOS_QUICKICON_MODULE', 1 );	

	function quickiconButton( $link, $image, $text ) {
		?>
		<div style="float:left;">
			<div class="icon">
				<a href="<?php echo $link; ?>">
					<?php echo mosAdminMenus::imageCheckAdmin( $image, '/administrator/images/', NULL, NULL, $text ); ?>
					<span><?php echo $text; ?></span>
				</a>
			</div>
		</div>
		<?php
	}
	
	$securitycheck 	= intval( $params->get( 'securitycheck', 1 ) );
	$versioncheck 	= intval( $params->get( 'versioncheck', 1 ) );
	$mbstringcheck	= intval( $params->get( 'mbstringcheck', 1 ) );
	?>
	<div id="cpanel">
		<?php
		$link = 'index2.php?option=com_content&amp;sectionid=0&amp;task=new';
		quickiconButton( $link, 'module.png', 'コンテンツアイテム追加' );
	
		$link = 'index2.php?option=com_content&sectionid=0';
		quickiconButton( $link, 'addedit.png', 'コンテンツアイテム管理' );
	
		$link = 'index2.php?option=com_typedcontent';
		quickiconButton( $link, 'addedit.png', '静的コンテンツ管理' );
	
		$link = 'index2.php?option=com_frontpage';
		quickiconButton( $link, 'frontpage.png', 'フロントページ管理' );
	
		$link = 'index2.php?option=com_sections&amp;scope=content';
		quickiconButton( $link, 'sections.png', 'セクション管理' );
	
		$link = 'index2.php?option=com_categories&amp;section=content';
		quickiconButton( $link, 'categories.png', 'カテゴリー管理' );
	
		$link = 'index2.php?option=com_media';
		quickiconButton( $link, 'mediamanager.png', 'メディア管理' );
	
		if ( $my->gid > 23 ) {
			$link = 'index2.php?option=com_trash';
			quickiconButton( $link, 'trash.png', 'ゴミ箱' );
		}
	
		if ( $my->gid > 23 ) {
			$link = 'index2.php?option=com_menumanager';
			quickiconButton( $link, 'menu.png', 'メニュー管理' );
		}
		
		if ( $my->gid > 24 ) {
			$link = 'index2.php?option=com_languages';
			quickiconButton( $link, 'langmanager.png', 'ランゲージ管理' );
		}
		
		if ( $my->gid > 23 ) {
			$link = 'index2.php?option=com_users';
			quickiconButton( $link, 'user.png', 'ユーザ管理' );
		}
	
		if ( $my->gid > 24 ) {
			$link = 'index2.php?option=com_config&hidemainmenu=1';
			quickiconButton( $link, 'config.png', 'グローバル・コンフィグレーション' );
		}
		/*
		$link = 'index2.php?option=com_admin&task=versioncheck';
		quickiconButton( $link, 'version_check.png', 'Version Check' );
		*/
		
		if ($versioncheck) {
		// show version check
			josVersionCheck('88%',0);
		}
		
		if ($securitycheck) {
		// show security setting check
			josSecurityCheck('88%');
		}
		if ($mbstringcheck) {
		// show security setting check
			josmbstringCheck('88%');
		}
		?>
	</div>
	<div style="clear:both;"> </div>	
	<?php
}
?>
